---
title: <span class="badge object-type-scalar"></span> MilliAmpereHour
---
# <span class="badge object-type-scalar"></span> MilliAmpereHour

Energy: Milliampere-hour (mAh)

## Definition

```python
# Energy: Milliampere-hour (mAh)
MilliAmpereHour: typing.Literal["mamph"] = "mamph"
```
